@@ -6,6 +6,7 @@ from djangomaster.views.settings import SettingsListView
 from djangomaster.views.signals import SignalsListView
 from djangomaster.views.lint import PyLintView, JsLintView
 from djangomaster.views.test import TestView, ExecuteTestView, CheckTestView
+from djangomaster.views.south import SouthView
 
 
 urlpatterns = patterns(
@@ -16,6 +17,7 @@ urlpatterns = patterns(
     url(r'^pylint/$', PyLintView.as_view(), name='pylint'),
     url(r'^jslint/$', JsLintView.as_view(), name='jslint'),
     url(r'^signals/$', SignalsListView.as_view(), name='signals'),
+    url(r'^south/$', SouthView.as_view(), name='south'),
 
     # Tests
     url(r'^test/$', TestView.as_view(), name='test'),
