@@ -54,7 +54,10 @@ class JSONResponseMixin(object):
 
 
 class JSONDetailView(JSONResponseMixin, BaseDetailView):
+    pass
 
+
+class MasterJSONView(JSONResponseMixin, ListView):
     @method_decorator(login_required)
     def dispach(self, *args, **kwargs):
         if not self.request.user.is_admin:
